@@ -1,4 +1,4 @@
-# Copyright 2015 Google Inc. All Rights Reserved.
+# Copyright 2015-2016 Google Inc. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -38,7 +38,7 @@ from yapf.yapflib import py3compat
 from yapf.yapflib import style
 from yapf.yapflib import yapf_api
 
-__version__ = '0.6.3'
+__version__ = '0.9.0'
 
 
 def main(argv):
@@ -103,9 +103,7 @@ def main(argv):
   parser.add_argument('--no-local-style',
                       action='store_true',
                       help="don't search for local style definition")
-  parser.add_argument('--verify',
-                      action='store_true',
-                      help='try to verify reformatted code for syntax errors')
+  parser.add_argument('--verify', action='store_true', help=argparse.SUPPRESS)
 
   parser.add_argument('files', nargs='*')
   args = parser.parse_args(argv[1:])
@@ -210,13 +208,13 @@ def FormatFiles(filenames,
           print_diff=print_diff,
           verify=verify,
           logger=logging.warning)
+      if has_change and reformatted_code is not None:
+        file_resources.WriteReformattedCode(filename, reformatted_code,
+                                            in_place, encoding)
       changed |= has_change
     except SyntaxError as e:
       e.filename = filename
       raise
-    if reformatted_code is not None:
-      file_resources.WriteReformattedCode(filename, reformatted_code, in_place,
-                                          encoding)
   return changed
 
 
